@@ -6,7 +6,7 @@ from httpx import AsyncClient
 from ..utils import adapter_selector
 
 if adapter_selector().upper() == "AUA":
-    plugin_config = Config.parse_obj(get_driver().config)
+    plugin_config = Config.parse_obj(get_driver().config.dict())
     aua_url = plugin_config.aua_url
     aua_ua = plugin_config.aua_ua
     if aua_url:
@@ -22,17 +22,30 @@ if adapter_selector().upper() == "AUA":
 
 headers = {"User-Agent": aua_ua}
 
+
 async def fetch_user_info(arcaea_id: str, recent_only: bool = False) -> List[Dict]:
     async with AsyncClient() as client:
         if recent_only:
             res = await client.get(
                 url=f"{aua_url}/botarcapi/user/info?usercode={arcaea_id}&recent=1&withsonginfo=true",
                 headers=headers,
-                timeout=100)
+                timeout=100,
+            )
             return res.json()
         else:
             res = await client.get(
                 url=f"{aua_url}/botarcapi/user/best30?usercode={arcaea_id}&overflow=10&withrecent=true&withsonginfo=true",
                 headers=headers,
-                timeout=100)
+                timeout=100,
+            )
             return res.json()
+
+
+async def get_user_best(arcaea_id: str, song_id: str, difficulty: str):
+    async with AsyncClient() as client:
+        resp = await client.get(
+            url=f"{aua_url}/botarcapi/user/best?usercode={arcaea_id}&songid={song_id}&difficulty={difficulty}&withrecent=true&withsonginfo=true",
+            headers=headers,
+            timeout=100,
+        )
+        return resp.json()
